==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/IntegrationAccountAssembly.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin

import com.pulumi.azurenative.logic.kotlin.outputs.AssemblyPropertiesResponse
import com.pulumi.azurenative.logic.kotlin.outputs.AssemblyPropertiesResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [IntegrationAccountAssembly].
 */
@PulumiTagMarker
public class IntegrationAccountAssemblyResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: IntegrationAccountAssemblyArgs = IntegrationAccountAssemblyArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend IntegrationAccountAssemblyArgsBuilder.() -> Unit) {
        val builder = IntegrationAccountAssemblyArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): IntegrationAccountAssembly {
        val builtJavaResource =
            com.pulumi.azurenative.logic.IntegrationAccountAssembly(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return IntegrationAccountAssembly(builtJavaResource)
    }
}

/**
 * The assembly definition.
 * Azure REST API version: 2019-05-01. Prior API version in Azure Native 1.x: 2019-05-01.
 * ## Example Usage
 * ### Create or update an account assembly
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var integrationAccountAssembly = new AzureNative.Logic.IntegrationAccountAssembly("integrationAccountAssembly", new()
 *     {
 *         AssemblyArtifactName = "testAssembly",
 *         IntegrationAccountName = "testIntegrationAccount",
 *         Location = "westus",
 *         Properties = new AzureNative.Logic.Inputs.AssemblyPropertiesArgs
 *         {
 *             AssemblyName = "System.IdentityModel.Tokens.Jwt",
 *             Content = "Base64 encoded Assembly Content",
 *             Metadata = null,
 *         },
 *         ResourceGroupName = "testResourceGroup",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/logic/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := logic.NewIntegrationAccountAssembly(ctx, "integrationAccountAssembly", &logic.IntegrationAccountAssemblyArgs{
 * 			AssemblyArtifactName:   pulumi.String("testAssembly"),
 * 			IntegrationAccountName: pulumi.String("testIntegrationAccount"),
 * 			Location:               pulumi.String("westus"),
 * 			Properties: &logic.AssemblyPropertiesArgs{
 * 				AssemblyName: pulumi.String("System.IdentityModel.Tokens.Jwt"),
 * 				Content:      pulumi.Any("Base64 encoded Assembly Content"),
 * 				Metadata:     nil,
 * 			},
 * 			ResourceGroupName: pulumi.String("testResourceGroup"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.logic.IntegrationAccountAssembly;
 * import com.pulumi.azurenative.logic.IntegrationAccountAssemblyArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var integrationAccountAssembly = new IntegrationAccountAssembly("integrationAccountAssembly", IntegrationAccountAssemblyArgs.builder()
 *             .assemblyArtifactName("testAssembly")
 *             .integrationAccountName("testIntegrationAccount")
 *             .location("westus")
 *             .properties(Map.ofEntries(
 *                 Map.entry("assemblyName", "System.IdentityModel.Tokens.Jwt"),
 *                 Map.entry("content", "Base64 encoded Assembly Content"),
 *                 Map.entry("metadata", )
 *             ))
 *             .resourceGroupName("testResourceGroup")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:logic:IntegrationAccountAssembly testAssembly /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Logic/integrationAccounts/{integrationAccountName}/assemblies/{assemblyArtifactName}
 * ```
 */
public class IntegrationAccountAssembly internal constructor(
    override val javaResource: com.pulumi.azurenative.logic.IntegrationAccountAssembly,
) : KotlinCustomResource(javaResource, IntegrationAccountAssemblyMapper) {
    /**
     * The resource location.
     */
    public val location: Output<String>?
        get() = javaResource.location().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Gets the resource name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The assembly properties.
     */
    public val properties: Output<AssemblyPropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * Gets the resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object IntegrationAccountAssemblyMapper : ResourceMapper<IntegrationAccountAssembly> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.logic.IntegrationAccountAssembly::class == javaResource::class

    override fun map(javaResource: Resource): IntegrationAccountAssembly =
        IntegrationAccountAssembly(
            javaResource as
                com.pulumi.azurenative.logic.IntegrationAccountAssembly,
        )
}

/**
 * @see [IntegrationAccountAssembly].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [IntegrationAccountAssembly].
 */
public suspend fun integrationAccountAssembly(
    name: String,
    block: suspend IntegrationAccountAssemblyResourceBuilder.() -> Unit,
):
    IntegrationAccountAssembly {
    val builder = IntegrationAccountAssemblyResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [IntegrationAccountAssembly].
 * @param name The _unique_ name of the resulting resource.
 */
public fun integrationAccountAssembly(name: String): IntegrationAccountAssembly {
    val builder = IntegrationAccountAssemblyResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/IntegrationAccountAssembly.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin

import com.pulumi.azurenative.logic.kotlin.outputs.AssemblyPropertiesResponse
import com.pulumi.azurenative.logic.kotlin.outputs.AssemblyPropertiesResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [IntegrationAccountAssembly].
 */
@PulumiTagMarker
public class IntegrationAccountAssemblyResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: IntegrationAccountAssemblyArgs = IntegrationAccountAssemblyArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend IntegrationAccountAssemblyArgsBuilder.() -> Unit) {
        val builder = IntegrationAccountAssemblyArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): IntegrationAccountAssembly {
        val builtJavaResource =
            com.pulumi.azurenative.logic.IntegrationAccountAssembly(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return IntegrationAccountAssembly(builtJavaResource)
    }
}

/**
 * The assembly definition.
 * Azure REST API version: 2019-05-01. Prior API version in Azure Native 1.x: 2019-05-01.
 * ## Example Usage
 * ### Create or update an account assembly
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var integrationAccountAssembly = new AzureNative.Logic.IntegrationAccountAssembly("integrationAccountAssembly", new()
 *     {
 *         AssemblyArtifactName = "testAssembly",
 *         IntegrationAccountName = "testIntegrationAccount",
 *         Location = "westus",
 *         Properties = new AzureNative.Logic.Inputs.AssemblyPropertiesArgs
 *         {
 *             AssemblyName = "System.IdentityModel.Tokens.Jwt",
 *             Content = "Base64 encoded Assembly Content",
 *             Metadata = null,
 *         },
 *         ResourceGroupName = "testResourceGroup",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/logic/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := logic.NewIntegrationAccountAssembly(ctx, "integrationAccountAssembly", &logic.IntegrationAccountAssemblyArgs{
 * 			AssemblyArtifactName:   pulumi.String("testAssembly"),
 * 			IntegrationAccountName: pulumi.String("testIntegrationAccount"),
 * 			Location:               pulumi.String("westus"),
 * 			Properties: &logic.AssemblyPropertiesArgs{
 * 				AssemblyName: pulumi.String("System.IdentityModel.Tokens.Jwt"),
 * 				Content:      pulumi.Any("Base64 encoded Assembly Content"),
 * 				Metadata:     pulumi.Any(nil),
 * 			},
 * 			ResourceGroupName: pulumi.String("testResourceGroup"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.logic.IntegrationAccountAssembly;
 * import com.pulumi.azurenative.logic.IntegrationAccountAssemblyArgs;
 * import com.pulumi.azurenative.logic.inputs.AssemblyPropertiesArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var integrationAccountAssembly = new IntegrationAccountAssembly("integrationAccountAssembly", IntegrationAccountAssemblyArgs.builder()
 *             .assemblyArtifactName("testAssembly")
 *             .integrationAccountName("testIntegrationAccount")
 *             .location("westus")
 *             .properties(AssemblyPropertiesArgs.builder()
 *                 .assemblyName("System.IdentityModel.Tokens.Jwt")
 *                 .content("Base64 encoded Assembly Content")
 *                 .metadata()
 *                 .build())
 *             .resourceGroupName("testResourceGroup")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:logic:IntegrationAccountAssembly testAssembly /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Logic/integrationAccounts/{integrationAccountName}/assemblies/{assemblyArtifactName}
 * ```
 */
public class IntegrationAccountAssembly internal constructor(
    override val javaResource: com.pulumi.azurenative.logic.IntegrationAccountAssembly,
) : KotlinCustomResource(javaResource, IntegrationAccountAssemblyMapper) {
    /**
     * The resource location.
     */
    public val location: Output<String>?
        get() = javaResource.location().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Gets the resource name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The assembly properties.
     */
    public val properties: Output<AssemblyPropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * Gets the resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object IntegrationAccountAssemblyMapper : ResourceMapper<IntegrationAccountAssembly> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.logic.IntegrationAccountAssembly::class == javaResource::class

    override fun map(javaResource: Resource): IntegrationAccountAssembly =
        IntegrationAccountAssembly(
            javaResource as
                com.pulumi.azurenative.logic.IntegrationAccountAssembly,
        )
}

/**
 * @see [IntegrationAccountAssembly].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [IntegrationAccountAssembly].
 */
public suspend fun integrationAccountAssembly(
    name: String,
    block: suspend IntegrationAccountAssemblyResourceBuilder.() -> Unit,
):
    IntegrationAccountAssembly {
    val builder = IntegrationAccountAssemblyResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [IntegrationAccountAssembly].
 * @param name The _unique_ name of the resulting resource.
 */
public fun integrationAccountAssembly(name: String): IntegrationAccountAssembly {
    val builder = IntegrationAccountAssemblyResourceBuilder()
    builder.name(name)
    return builder.build()
}
